import argparse
import os
import subprocess


def main():
    prser = argparse.ArgumentParser(description="stress test a program with multiple inputs")
    prser.add_argument("file", metavar="prgm.py", type=str, nargs=1, help="program to test")
    prser.add_argument("test", metavar="testdir", type=str, nargs=1, help="directory of test cases")

    args = prser.parse_args()

    wa = True
    if (os.path.exists(os.path.join(os.path.abspath(os.getcwd()), str(args.file[0])))
            and os.path.exists(os.path.join(os.path.abspath(os.getcwd()), str(args.test[0])))):
        wa = False
        for sb, _, f in os.walk(os.path.join(os.path.abspath(os.getcwd()), str(args.test[0]))):
            for i in f:
                pth = sb + os.sep + i
                if pth.endswith(".in"):
                    with open(pth, "r", encoding="utf-8") as fin:
                        p = subprocess.Popen(["python", str(args.file[0])], stdin=fin, stdout=subprocess.PIPE,
                                             stderr=subprocess.PIPE)
                        out, err = p.communicate()
                        if not err:
                            out = out.decode("utf-8").strip()
                            arr = [o for o in os.listdir(str(args.test[0]))]

                            fn = i[:i.index(".")] + ".out"

                            if fn not in arr:
                                print("no output file for", i)
                                break

                            of = open(sb + os.sep + fn, "r", encoding="utf-8")

                            if out != of.read().strip():
                                print("Wrong Answer on", i)
                                print("Output: ", out)
                                print("\nExpected:", of.read().strip())
                                wa = True
                                break
                        else:
                            print("Runtime Error on", i)
                            print(err)
                            wa = True
                            break
    else:
        print("Files not found")
    if not wa:
        print("All cases passed.")



from setuptools import setup, find_packages

long_description = open("README.md").read()

setup(
    name='stresst',
    version='0.0.9',
    author='Ryan Chou',
    author_email='',
    url='https://ryanchou.dev',
    description='Stress test your Python solutions!',
    long_description=long_description,
    long_description_content_type="text/markdown",
    license='MIT',
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'stresst = stresst.strs:main'
        ]
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    keywords='competitive-programming python problems testing',
    install_requires="",
    zip_safe=False
)
